#!/bin/bash
DEVID=PIC12F683
PKCMD=./PK2CMD.exe
function deviceinfo {
    echo "PIC Device Info:"
    # sed -n '1!G;h;$p' # invert line order
    $PKCMD -P$DEVID -I | sed -n '1h;2H;3G;3p'
    MID=`$PKCMD -P$DEVID -GI | grep -E '([0-9A-Fa-f]{4}.+){4}'`
    printf "\nMemory ID = $MID\n"
    printf "Frameware = %d\nDevice SN = %d\n" $(printf "0x%s %.s%.s" $MID)
}

if [ "$1" == "--help" ]; then
    echo "Usage: $0 [FRAMEWARE] [DEVICE_ID]" 
    exit
fi

if [ ! -f "PK2CMD.exe" ]; then
    echo "Nie odnaleziono PK2CMD.exe!"
    exit
fi

MSG=$($PKCMD -P$DEVID)
RETVAL=$?
if [ $RETVAL -ne 0 ]; then
    echo "$RETVAL"
    echo "$MSG"
    exit
fi

deviceinfo

# Stop if no args
[ $# -ne 2 ] && exit

if [ $1 -ge 256 ]; then
    echo "Wersja musi być mniejsza niż 256"
    exit
fi
if [ $2 -ge 16000 ]; then
    echo "Device ID musi być mniejsze niż 16 tys.!!!"
    exit
fi

FILE=`printf "main-v%02d.HEX" $1`
if [ ! -f $FILE ]; then
    echo "Brak Frameware w wersji $1! ($FILE)"
    exit
fi

# Prepare ID File
# ID File Example: (06 00 00 0A)
# :08400000 0600 0000 0000 0A00 00
# :00000001FF
FullID=$2
LoID=$((FullID&0xFF))
HiID=$((FullID>>8))
printf ":08400000%02X0000000000%02X%02X00" "$1" "$LoID" "$HiID" > id.tmp 2> /dev/null;
printf ":00000001FF" >> id.tmp;

printf "Erasse... "
$PKCMD -P$DEVID -E > /dev/null # Print Device Info & Erase
printf "OK!\n"

printf "Set ID... "
$PKCMD -P$DEVID -Fid.tmp -MI > /dev/null # Set ID
RETVAL=$?
if [ $RETVAL -ne 0 ]; then
    printf "\nProblem z ustawieniem ID X%02X0000%02X\n" $1 $2
    exit
fi
printf "OK!\n"

printf "Programing... "
$PKCMD -P$DEVID "-F$FILE" -MP -MC > /dev/null # Program & Lock Device
RETVAL=$?
if [ $RETVAL -ne 0 ]; then
    printf "\nNieoczekiwany bląd podczas programowania :(\n"
    exit
fi
printf "OK!\n\n"

deviceinfo

./poweron.sh
